ghci-quickfix-0.1.0.0: GHC plugin that writes errors to a file for use with quickfix
Safe HaskellNone
LanguageGHC2021

GhciQuickfix

Synopsis

Documentation

pluginOffByDefault :: Plugin Source #

For use with repl-alliance, where this plugin should be off by default